@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/libraries/libldap/open.c,v 1.30.2.8 2000/09/03 16:17:31 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/libraries/libldap/open.c,v 1.30.2.9 2000/09/07 00:11:25 kurt Exp $ */
 /*
  * Copyright 1998-2000 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -322,8 +322,8 @@ ldap_int_open_connection(
 	}
 #endif
 
-	if ( conn->lconn_krbinstance != NULL ) {
 #ifdef LDAP_API_FEATURE_X_OPENLDAP_V2_KBIND
+	if ( conn->lconn_krbinstance == NULL ) {
 		char *c;
 		conn->lconn_krbinstance = ldap_host_connected_to( conn->sb );
 
@@ -331,10 +331,8 @@ ldap_int_open_connection(
 		    ( c = strchr( conn->lconn_krbinstance, '.' )) != NULL ) {
 			*c = '\0';
 		}
-#else /* LDAP_API_FEATURE_X_OPENLDAP_V2_KBIND */
-		conn->lconn_krbinstance = NULL;
-#endif /* LDAP_API_FEATURE_X_OPENLDAP_V2_KBIND */
 	}
+#endif /* LDAP_API_FEATURE_X_OPENLDAP_V2_KBIND */
 
 	return( 0 );
 }
